summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPeter Hutterer <peter.hutterer@who-t.net>2019-02-04 09:56:45 +1000
committerPeter Hutterer <peter.hutterer@who-t.net>2019-02-04 09:56:45 +1000
commitfbe7abfd5d1abc25cc3641efcf056971489bed99 (patch)
tree004558ea849064462c6047ecbd1905cc5be08e91
parent6a720eb582d57891b2bef9abc37e8db555ee3e35 (diff)
downloadlibinput-fbe7abfd5d1abc25cc3641efcf056971489bed99.tar.gz
test: up the ratelimit tests to 1000ms
This fails too often on the gitlab runners, so let's expand the times. Signed-off-by: Peter Hutterer <peter.hutterer@who-t.net>
-rw-r--r--test/test-misc.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/test-misc.c b/test/test-misc.c
index 7cc94c5a..748c07bd 100644
--- a/test/test-misc.c
+++ b/test/test-misc.c
@@ -702,8 +702,8 @@ START_TEST(ratelimit_helpers)
struct ratelimit rl;
unsigned int i, j;
- /* 10 attempts every 100ms */
- ratelimit_init(&rl, ms2us(500), 10);
+ /* 10 attempts every 1000ms */
+ ratelimit_init(&rl, ms2us(1000), 10);
for (j = 0; j < 3; ++j) {
/* a burst of 9 attempts must succeed */
@@ -731,8 +731,8 @@ START_TEST(ratelimit_helpers)
RATELIMIT_EXCEEDED);
}
- /* but after 500ms the counter is reset */
- msleep(450); /* +50ms to account for time drifts */
+ /* but after 1000ms the counter is reset */
+ msleep(950); /* +50ms to account for time drifts */
}
}
END_TEST